Version 0.1 du 23 août 2017

# OpenBackloggery

Logiciel web permettant de :

  * lister sa collection de jeux vidéos
  * connaître sa progression sur chacun des jeux (jamais joué, terminé, complété, etc.)
  * avoir une liste de jeux souhaités
  * savoir à quel jeu nous jouons actuellement
  * garder un historique de quand nous avons acquis le jeu, quand nous l'avons terminé, etc.

[![Python 3.6](https://img.shields.io/badge/python-3.6-green.svg)](http://python.org/)
[![Django 1.11](https://img.shields.io/badge/django-1.11-green.svg)](http://djangoproject.com/)
[![SQLite 3](https://img.shields.io/badge/SQLite-3-green.svg)](http://sqlite.org/)

# Installation

En s'appuyant sur [Docker](https://www.docker.com/), l'installation se déroule en plusieurs étapes : 

  * la création d'une image Docker
  * la création d'un dossier pour la base de données et la génération de cette dernière
  * la création d'un utilisateur administrateur de la base de données (l'utilisateur principal)
  * le lancement d'un conteneur Docker permettant d'accéder à l'interface Web de l'application

## Création de l'image Docker

Nous appelerons notre image Docker **openbackloggery**. Nous considéréons que l'application se trouver dans un dossier nommé **openbackloggery** dans lequel se trouve un fichier *Dockerfile*.

```bash
cd openbackloggery
docker build -t openbackloggery:0.1 .
```

## Base de données

Actuellement nous utilisons SQLite3 comme base de données car les fonctionnalités et la quantité de données ne requièrent pas un gestionnaire de base de données plus conséquent.

```bash
mkdir /openbackloggery_db
docker run -it --rm -v /openbackloggery_db:/opt/apps/db openbackloggery:0.1 python3 manage.py migrate
docker run -it --rm -v /openbackloggery_db:/opt/apps/db openbackloggery:0.1 python3 manage.py loaddata initial
```

*loaddata initial* permet de charger quelques données initiales comme une liste de consoles par exemple.

## Création d'un utilisateur admin

Adaptez la ligne en remplaçant **admin** par le nom d'utilisateur que vous voulez et **admin@domaine.tld** par l'adresse courriel de votre choix (qu'elle existe ou non importe peu pour l'instant car elle n'est pas utilisée).

```bash
docker run -it --rm -v /openbackloggery_db:/opt/apps/db openbackloggery:0.1 python3 manage.py createsuperuser --user=admin --email=admin@domaine.tld
```

## Lancement du conteneur Docker

Le service se lancera sur le **port 8282** et aura pour clé secrète **abcdefghijk** : 

```bash
docker run -d -e SECRET_KEY='abcdefghijk' -v /openbackloggery_db:/opt/apps/db -p 8282:8000 openbackloggery:0.1
```

Veillez à modifier la clé secrète par une chaîne de caractère aléatoire assez longue et parsemée de majuscules, minuscules, ponctuation, etc.

## Accès à l'application

Une fois le conteneur Docker lancé, il suffit d'ouvrir un navigateur Internet et d'y taper l'adresse suivante : http://127.0.0.1:8282/admin/.

# Licence

Ce logiciel est concédé sous [licence EUPL, version 1.2 uniquement](https://joinup.ec.europa.eu/community/eupl/og_page/eupl-text-11-12).

# Contact

Le projet est disponible sur [la forge de Papa Ogre](https://forge.o9.re/olivier/openbackloggery/).

Ou alors vous pouvez [contacter l'auteur par courriel](mailto:git@dossmann.net).
